[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#597054: python-apt: use only this patch



Package: python-apt
Version: 0.8.0~exp4
Followup-For: Bug #597054

This bug report has too many patches which are rather unrelated. Please close
it with this one, which only fixes a few typos. Some variation of the other
patches are submitted as separate bug reports to ease review.
=== modified file 'apt/package.py'
--- apt/package.py	2011-05-13 17:09:11 +0000
+++ apt/package.py	2011-05-13 19:05:43 +0000
@@ -343,7 +343,7 @@
     def description(self):
         """Return the formatted long description.
 
         Return the formated long description according to the Debian policy
         (Chapter 5.6.13).
         See http://www.debian.org/doc/debian-policy/ch-controlfields.html
         for more information.
@@ -892,7 +892,7 @@
     def description(self):
         """Return the formatted long description.
 
         Return the formated long description according to the Debian policy
         (Chapter 5.6.13).
         See http://www.debian.org/doc/debian-policy/ch-controlfields.html
         for more information.
@@ -1360,8 +1360,8 @@
     print "SourcePkg: %s " % pkg.candidate.source_name
     print "Section: %s " % pkg.section
     print "Summary: %s" % pkg.candidate.summary
-    print "Description (formated) :\n%s" % pkg.candidate.description
-    print "Description (unformated):\n%s" % pkg.candidate.raw_description
+    print "Description (formatted) :\n%s" % pkg.candidate.description
+    print "Description (unformatted):\n%s" % pkg.candidate.raw_description
     print "InstalledSize: %s " % pkg.candidate.installed_size
     print "PackageSize: %s " % pkg.candidate.size
     print "Dependencies: %s" % pkg.installed.dependencies
@@ -343,7 +343,7 @@
         """Return the formatted long description.
 
-        Return the formated long description according to the Debian policy
+        Return the formatted long description according to the Debian policy
         (Chapter 5.6.13).
         See http://www.debian.org/doc/debian-policy/ch-controlfields.html
@@ -892,7 +892,7 @@
         """Return the formatted long description.
 
-        Return the formated long description according to the Debian policy
+        Return the formatted long description according to the Debian policy
         (Chapter 5.6.13).
         See http://www.debian.org/doc/debian-policy/ch-controlfields.html


Reply to: